Least Squares
=============

.. inheritance-diagram:: gmmvi.optimization.least_squares.RegressionFunc gmmvi.optimization.least_squares.LinFunc gmmvi.optimization.least_squares.QuadFunc
    :parts: -3

.. automodule:: gmmvi.optimization.least_squares
   :members:

